==> wurld-0.3.tar.gz: wurld-0.3/src/PythonPlugin.cc <==

#include "PythonPlugin.h"

// prototype for getDisplayDriver
#include "PythonPluginInternal.h"
#include "PythonObject.h"
#include "Vector.h"
#include "Texture.h"
#include "TextureMaterial.h"
#include "QuadObj.h"
#include "Model.h"
#include "Moveable.h"
#include "Graphics.h"
#include "PythonKeyCommand.h"
#include "TextBuffer.h"
#include "TextPane.h"
#include "FPSDisplay.h"
#include "PointCollisionAlgo.h"
#include "config.h"

#include <Python.h>

DisplayDriver *PythonPlugin::displayDriver;
DisplayDriver *getDisplayDriver() {
   return PythonPlugin::displayDriver;
}

void PythonPlugin::setDisplayDriver(DisplayDriver *driver) {
   displayDriver = driver;
}

GameEngine *PythonPlugin::gameEngine;
GameEngine *getGameEngine() {
   return PythonPlugin::gameEngine;
}

RotMatrix createYawRotMatrix(Float degrees) {
   RotMatrix rot;
   rot.makeYaw(degrees);
   return rot;
}

RotMatrix createPitchRotMatrix(Float degrees) {
   RotMatrix rot;
   rot.makePitch(degrees);
   return rot;
}

RotMatrix createRollRotMatrix(Float degrees) {
   RotMatrix rot;
   rot.makeRoll(degrees);
   return rot;
}

void PythonPlugin::setGameEngine(GameEngine *engine) {
   gameEngine = engine;
}

Vector createVector(Float x, Float y, Float z) {
   return Vector(x, y, z);
}

TexturePtr createTexture(const char *filename) {
   return new Texture(filename);
}

MaterialPtr createTextureMaterial(const TexturePtr &texture, 
                                  Float xppus, 
				  Float yppus
				  ) {
   return new TextureMaterial(texture, xppus, yppus);
}

PolyObjPtr createQuad(Vector c0, Vector c1, Vector c2, Vector c3,
		      const MaterialPtr &material
		      ) {
   return new QuadObj(c0, c1, c2, c3, material);
}

ModelPtr createModel() {
   return new Model();
}

SimpleCollidablePtr createSimpleCollidable(const AxisBox &box) {
   return new SimpleCollidable(box);
}

CollisionAlgoPtr createPointCollisionAlgo() {
   static CollisionAlgoPtr algo;
   if (!algo)
      algo = new PointCollisionAlgo();
   return algo;
}

MoveablePtr createMoveable() {
   return new Moveable();
}

RenderableObjectPtr createSimpleText(const char *text, Float left, Float top,
                                     Float width,
                                     Float height
                                     ) {
   return new TextPane(new TextBuffer(text), left, top, width, height);
}

RenderableObjectPtr createFPSDisplay(GameEngine *engine) {
   return new FPSDisplay(*engine);
}

PythonObject *createPythonObject() {
   return new PythonObject();
}

Graphics *getGraphics() {
   return &Graphics::getInstance();
}

char *getVersion() {
   return (char *)PACKAGE_VERSION;
}

KeyCommandPtr createKeyCommand(PyObject *onKeyPress,
                               PyObject *onKeyRelease
                               ) {
   return new PythonKeyCommand(onKeyPress, onKeyRelease);
}

extern "C" void initwurld();

void PythonPlugin::handleInit() {
   Py_Initialize();
   initwurld();
   FILE *fp = fopen("wurldrc.py", "r");
   if (!fp)
      throw PluginError("Unable to load startup file wurldrc.py");
   PyRun_AnyFile(fp, "wurldrc.py");
}

void PythonPlugin::handleTerminate() {
   Py_Finalize();
}

==> wurld-0.4.tar.gz: wurld-0.4/src/PythonPlugin.cc <==

#include "PythonPlugin.h"

// prototype for getDisplayDriver
#include "PythonPluginInternal.h"
#include "PythonObject.h"
#include "Vector.h"
#include "Texture.h"
#include "TextureMaterial.h"
#include "ColorMaterial.h"
#include "QuadObj.h"
#include "SphereObj.h"
#include "Model.h"
#include "Moveable.h"
#include "Graphics.h"
#include "PythonKeyCommand.h"
#include "TextBuffer.h"
#include "TextPane.h"
#include "QuadPane.h"
#include "FPSDisplay.h"
#include "PointCollisionAlgo.h"
#include "config.h"

#include <Python.h>

DisplayDriver *PythonPlugin::displayDriver;
DisplayDriver *getDisplayDriver() {
   return PythonPlugin::displayDriver;
}

void PythonPlugin::setDisplayDriver(DisplayDriver *driver) {
   displayDriver = driver;
}

GameEngine *PythonPlugin::gameEngine;
GameEngine *getGameEngine() {
   return PythonPlugin::gameEngine;
}

RotMatrix createYawRotMatrix(Float degrees) {
   RotMatrix rot;
   rot.makeYaw(degrees);
   return rot;
}

RotMatrix createPitchRotMatrix(Float degrees) {
   RotMatrix rot;
   rot.makePitch(degrees);
   return rot;
}

RotMatrix createRollRotMatrix(Float degrees) {
   RotMatrix rot;
   rot.makeRoll(degrees);
   return rot;
}

void PythonPlugin::setGameEngine(GameEngine *engine) {
   gameEngine = engine;
}

Vector createVector(Float x, Float y, Float z) {
   return Vector(x, y, z);
}

Color createColor(Float red, Float green, Float blue) {
   return Color(red, green, blue);
}

MaterialPtr createColorMaterial(const Color &color) {
   return new ColorMaterial(color);
}

TexturePtr createTexture(const char *filename) {
   return new Texture(filename);
}

MaterialPtr createTextureMaterial(const TexturePtr &texture, 
                                  Float xppus, 
				  Float yppus
				  ) {
   return new TextureMaterial(texture, xppus, yppus);
}

PolyObjPtr createQuad(Vector c0, Vector c1, Vector c2, Vector c3,
		      const MaterialPtr &material
		      ) {
   return new QuadObj(c0, c1, c2, c3, material);
}

SphereObjPtr createSphereObj(const Vector &center, Float radius, 
                             const MaterialPtr &material
                             ) {
   return new SphereObj(center, radius, material);
}

ModelPtr createModel() {
   return new Model();
}

SimpleCollidablePtr createSimpleCollidable(const AxisBox &box) {
   return new SimpleCollidable(box);
}

CollisionAlgoPtr createPointCollisionAlgo() {
   static CollisionAlgoPtr algo;
   if (!algo)
      algo = new PointCollisionAlgo();
   return algo;
}

MoveablePtr createMoveable() {
   return new Moveable();
}

TextPanePtr createSimpleText(const char *text, Float left, Float top,
                             Float width,
                             Float height
                             ) {
   return new TextPane(new TextBuffer(text), left, top, width, height);
}

QuadPanePtr createQuadPane(Float left, Float top, Float width, Float height,
                           const MaterialPtr &material
                           ) {
   return new QuadPane(left, top, width, height, material);
}

RenderableObjectPtr createFPSDisplay(GameEngine *engine) {
   return new FPSDisplay(*engine);
}

PythonObject *createPythonObject() {
   return new PythonObject();
}

Graphics *getGraphics() {
   return &Graphics::getInstance();
}

AudioDriver *PythonPlugin::audioDriver;
AudioDriver *getAudioDriver() {
   return PythonPlugin::audioDriver;
}

void PythonPlugin::setAudioDriver(AudioDriver *driver) {
   audioDriver = driver;
}

char *getVersion() {
   return (char *)PACKAGE_VERSION;
}

KeyCommandPtr createKeyCommand(PyObject *onKeyPress,
                               PyObject *onKeyRelease
                               ) {
   return new PythonKeyCommand(onKeyPress, onKeyRelease);
}

extern "C" void initwurld();

void PythonPlugin::handleInit() {
   Py_Initialize();
   initwurld();
   FILE *fp = fopen("wurldrc.py", "r");
   if (!fp)
      throw PluginError("Unable to load startup file wurldrc.py");
   PyRun_AnyFile(fp, "wurldrc.py");
}

void PythonPlugin::handleTerminate() {
   Py_Finalize();
}
